from typing import *


def average(a: numpy.ma.core.MaskedArray, weights: Union[numpy.ndarray, None]):
    """
    usage.sklearn: 8
    """
    ...


def masked_all(shape: Tuple[int, ...]):
    """
    usage.pandas: 14
    """
    ...


def median(a: numpy.ma.core.MaskedArray, axis: int):
    """
    usage.sklearn: 1
    """
    ...
